========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - | |travis| |appveyor| |requires|
        | |codecov|
    * - package
      - | |version|

.. |docs| image:: https://readthedocs.org/projects/kitovu/badge/?style=flat
    :target: https://readthedocs.org/projects/kitovu
    :alt: Documentation Status

.. |travis| image:: https://travis-ci.org/kitovu-bot/kitovu.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/kitovu-bot/kitovu

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/kitovu-bot/kitovu?branch=master&svg=true
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/kitovu-bot/kitovu

.. |requires| image:: https://requires.io/github/kitovu-bot/kitovu/requirements.svg?branch=master
    :alt: Requirements Status
    :target: https://requires.io/github/kitovu-bot/kitovu/requirements/?branch=master

.. |codecov| image:: https://codecov.io/github/kitovu-bot/kitovu/coverage.svg?branch=master
    :alt: Coverage Status
    :target: https://codecov.io/github/kitovu-bot/kitovu

.. |version| image:: https://img.shields.io/pypi/v/kitovu.svg
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/kitovu

.. end-badges

OpenHSR Connect 2

* Free software: GNU GPL v3

Installation
============

::

    pip install kitovu

Documentation
=============

https://kitovu.readthedocs.io/

Development
===========

To run the all tests run::

    tox
